import 'package:equatable/equatable.dart';
import 'package:flutter/material.dart';
import 'package:rollee_flutter_sdk/core/utils/helpers/helpers.dart';

/// {@template rollee_connect_config_setup}
/// This class represents the Rollee Connect configuration setup.
/// {@endtemplate}
@immutable
class RolleeConnectConfigSetup extends Equatable {
  /// whether the Rollee Connect is in production mode or not.
  final bool isProduction;

  /// the title of the intro screen.
  final String? introScreenTitle;

  /// the text color of the CTA button.
  final Color? ctaTextColor;

  /// the background color of the CTA button.
  final Color? ctaBackgroundColor;

  /// the partner logo url.
  final String? partnerLogoUrl;

  /// the redirect url.
  final String? redirectUrl;

  /// the data source.
  final String? dataSource;

  /// whether to skip the intro screen or not.
  final bool? introScreenSkip;

  /// whether to skip the data sources page or not.
  final bool? skipDataSourcesPage;

  /// whether to remove the close button or not.
  final bool? removeCloseButton;

  /// {@macro rollee_connect_config_setup}
  RolleeConnectConfigSetup({
    required this.isProduction,
    this.introScreenTitle,
    this.ctaTextColor,
    this.ctaBackgroundColor,
    this.partnerLogoUrl,
    this.redirectUrl,
    this.dataSource,
    this.introScreenSkip,
    this.skipDataSourcesPage,
    this.removeCloseButton,
  }) {
    if (redirectUrl != null) {
      assert(
        RolleeHelpers.isValidUrl(redirectUrl!),
        "The provided value of redirectUrl is not a valid URL.",
      );
    }
    if (partnerLogoUrl != null) {
      assert(
        RolleeHelpers.isValidUrl(partnerLogoUrl!),
        "The provided value of partnerLogoUrl is not a valid URL.",
      );
    }
  }

  @override
  List<Object?> get props => [
        isProduction,
        introScreenTitle,
        ctaTextColor,
        ctaBackgroundColor,
        partnerLogoUrl,
        redirectUrl,
        dataSource,
        introScreenSkip,
        skipDataSourcesPage,
        removeCloseButton,
      ];

  @override
  bool get stringify => true;
}
