// ignore_for_file: public_member_api_docs, sort_constructors_first
import 'package:equatable/equatable.dart';
import 'package:meta/meta.dart';

/// {@template rollee_connect_params}
/// This class represents the Rollee Connect parameters.
/// {@endtemplate}
@immutable
class RolleeConnectParams extends Equatable {
  /// the title of the intro screen.
  final String? introScreenTitle;

  /// the text color of the CTA button.
  final String? ctaButtonForeColor;

  /// the background color of the CTA button.
  final String? ctaButtonBackColor;

  /// the partner logo url.
  final String? partnerLogo;

  /// the redirect url.
  final String? redirect;

  /// {@macro rollee_connect_params}
  const RolleeConnectParams({
    this.introScreenTitle,
    this.ctaButtonForeColor,
    this.ctaButtonBackColor,
    this.partnerLogo,
    this.redirect,
  });

  @override
  List<Object?> get props => [
        introScreenTitle,
        ctaButtonForeColor,
        ctaButtonBackColor,
        partnerLogo,
        redirect,
      ];

  /// Creates a [Map] from the [RolleeConnectParams] object.
  /// This is used to pass the parameters to the native side.
  Map<String, dynamic> toMap() {
    return <String, dynamic>{
      'intro_screen_title': introScreenTitle,
      'cta_button_forecolor': ctaButtonForeColor,
      'cta_button_backcolor': ctaButtonBackColor,
      'partner_logo': partnerLogo,
      'redirect': redirect,
    };
  }


  @override
  bool get stringify => true;
}
