import 'dart:convert';

import 'package:meta/meta.dart';
import 'package:webview_flutter/webview_flutter.dart';

import '../../models/export.dart';
import 'logger.dart';

/// {@template Rollee_channel}
/// This class represents the method(s) used to communicate with the web view of Rollee Connect.
/// {@endtemplate}
@immutable
abstract class RolleeChannel {
  /// This the method used to communicate with the web view of Rollee Connect.
  static onMessage(
    JavaScriptMessage jsMessage, {
    required RolleeConnectConfig config,
    required Function(RolleeConnectResult result) onCompletedHandler,
    required Function(bool close) onCloseHandler,
    required Function(RolleeConnectLoginResult loginResult)
        onLoginSuccessHandler,
    required Function() onHomeHandler,
    required Function() onTermsHandler,
    required Function() onSearchHandler,
    required Function() onLoginHandler,
    required Function() onFetchHandler,
    required Function() onConnectedHandler,
  }) {
    String rawMessage = jsMessage.message;
    String firstLetter = rawMessage.substring(0, 1);
    bool isNotAJsonMessage = firstLetter != "{";

    if (isNotAJsonMessage) {
      switch (rawMessage) {
        case 'closeSession':
          RolleeLogger.connectLog("Session's close triggered.");
          onCloseHandler(true);
          break;

        case 'Home':
          RolleeLogger.connectLog("Home screen triggered.");
          onHomeHandler();
          break;
        case 'Terms':
          RolleeLogger.connectLog("Terms screen triggered.");
          onTermsHandler();
          break;

        case 'Search':
          RolleeLogger.connectLog("Search screen triggered.");
          onSearchHandler();
          break;

        case 'Login':
          RolleeLogger.connectLog("Login screen triggered.");
          onLoginHandler();
          break;

        case 'Fetch':
          RolleeLogger.connectLog("Fetch screen triggered.");
          onFetchHandler();
          break;

        case 'Connected':
          RolleeLogger.connectLog("Connected screen triggered.");
          onConnectedHandler();
          break;

        default:
          RolleeLogger.connectLog("An unexpected message is posted from RolleeConnect widget.");

          break;
      }
    } else {
      assert(rawMessage.startsWith("{") && rawMessage.endsWith("}"));

      Map<String, dynamic> decodedMessage =
          jsonDecode(rawMessage) as Map<String, dynamic>;
      bool onCompleted = decodedMessage["onCompleted"] ?? false;
      bool onLoginSuccess = decodedMessage["onLoginSuccess"] ?? false;

      if (onCompleted) {
        RolleeLogger.connectLog("onCompleted triggered");

        onCompletedHandler(
          RolleeConnectResult(
            isCompleted: true,
            userUUID: decodedMessage["userUUID"],
          ),
        );
      } else if (onLoginSuccess) {
        RolleeLogger.connectLog("onLoginSuccess triggered");

        onLoginSuccessHandler(
          RolleeConnectLoginResult(
            isCompleted: true,
            accountId: decodedMessage["accountID"],
            dataSourceId: decodedMessage["datasourceID"],
          ),
        );
      }
    }
  }
}
